@@ -175,7 +175,10 @@ class Lens(Graph):
                 sp.text = u" (%s) " % value.language
                 elem.append(sp)
                 self.rst(elem, value)
-            elif value.datatype:
+                elem.set("xml:lang", value.language)
+            else:
+                elem.set("xml:lang", "")
+            if value.datatype:
                 if value.datatype == XSD["dateTime"]:
                     try:
                         dt = datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%f")
@@ -184,6 +187,7 @@ class Lens(Graph):
                         elem.text = value
                 else:
                     elem.text = value
+                elem.set("datatype", value.datatype)
             else:
                 self.rst(elem, value)
         elif isinstance(value, URIRef) or isinstance(value, BNode):
